==> mapmyindia_gl-0.1.4.tar.gz: ios/Classes/SwiftMapboxGlFlutterPlugin.swift <==
import Flutter
import UIKit
import MapmyIndiaAPIKit

public class SwiftMapboxGlFlutterPlugin: NSObject, FlutterPlugin {
    public static func register(with registrar: FlutterPluginRegistrar) {
        let instance = MapboxMapFactory(withRegistrar: registrar)
        registrar.register(instance, withId: "plugins.flutter.io/mapbox_gl")

        let channel = FlutterMethodChannel(name: "plugins.flutter.io/mapbox_gl", binaryMessenger: registrar.messenger())

        channel.setMethodCallHandler { (methodCall, result) in
            switch(methodCall.method) {
            case "installOfflineMapTiles":
                guard let arguments = methodCall.arguments as? [String: String] else { return }
                let tilesdb = arguments["tilesdb"]
                installOfflineMapTiles(registrar: registrar, tilesdb: tilesdb!)
                result(nil)

            case "setRestAPIKey":
                guard let argumentsRestAPIKey = methodCall.arguments as? [String: String] else { return }
                let restAPIKey = argumentsRestAPIKey["restAPIKey"]
              
                MapmyIndiaAccountManager.setRestAPIKey(restAPIKey)
                result(nil)
                
            case "setMapSDKKey":
                guard let arguments = methodCall.arguments as? [String: String] else { return }
                let mapSDKKey = arguments["mapSDKKey"]
                MapmyIndiaAccountManager.setMapSDKKey(mapSDKKey)
                result(nil)
                
            case "setAtlasClientId":
                guard let arguments = methodCall.arguments as? [String: String] else { return }
                let atlasClientId = arguments["atlasClientId"]
                MapmyIndiaAccountManager.setAtlasGrantType("client_credentials")
                MapmyIndiaAccountManager.setAtlasClientId(atlasClientId)
                result(nil)
                
            case "setAtlasClientSecret":
                guard let arguments = methodCall.arguments as? [String: String] else { return }
                let atlasClientSecret = arguments["atlasClientSecret"]
                MapmyIndiaAccountManager.setAtlasClientSecret(atlasClientSecret)
                result(nil)
                
            case "setAtlasGrantType":
                guard let arguments = methodCall.arguments as? [String: String] else { return }
                let atlasGrantType = arguments["atlasGrantType"]
                MapmyIndiaAccountManager.setAtlasGrantType(atlasGrantType)
                result(nil)
                
            default:
                result(FlutterMethodNotImplemented)
            }
        }
    }

    private static func getTilesUrl() -> URL {
        guard var cachesUrl = FileManager.default.urls(for: .applicationSupportDirectory, in: .userDomainMask).first,
            let bundleId = Bundle.main.object(forInfoDictionaryKey: kCFBundleIdentifierKey as String) as? String else {
                fatalError("Could not get map tiles directory")
        }
        cachesUrl.appendPathComponent(bundleId)
        cachesUrl.appendPathComponent(".mapbox")
        cachesUrl.appendPathComponent("cache.db")
        return cachesUrl
    }

    // Copies the "offline" tiles to where Mapbox expects them
    private static func installOfflineMapTiles(registrar: FlutterPluginRegistrar, tilesdb: String) {
        var tilesUrl = getTilesUrl()
        let bundlePath = getTilesDbPath(registrar: registrar, tilesdb: tilesdb)
        NSLog("Cached tiles not found, copying from bundle... \(String(describing: bundlePath)) ==> \(tilesUrl)")
        do {
            let parentDir = tilesUrl.deletingLastPathComponent()
            try FileManager.default.createDirectory(at: parentDir, withIntermediateDirectories: true, attributes: nil)
            if FileManager.default.fileExists(atPath: tilesUrl.path) {
                try FileManager.default.removeItem(atPath: tilesUrl.path)
            }
            try FileManager.default.copyItem(atPath: bundlePath!, toPath: tilesUrl.path)
            var resourceValues = URLResourceValues()
            resourceValues.isExcludedFromBackup = true
            try tilesUrl.setResourceValues(resourceValues)
        } catch let error {
            NSLog("Error copying bundled tiles: \(error)")
        }
    }
    
    private static func getTilesDbPath(registrar: FlutterPluginRegistrar, tilesdb: String) -> String? {
        if (tilesdb.starts(with: "/")) {
            return tilesdb;
        } else {
            let key = registrar.lookupKey(forAsset: tilesdb)
            return Bundle.main.path(forResource: key, ofType: nil)
        }
    }
}

==> mapmyindia_gl-0.1.5.tar.gz: ios/Classes/SwiftMapboxGlFlutterPlugin.swift <==
import Flutter
import UIKit
import MapmyIndiaAPIKit

public class SwiftMapboxGlFlutterPlugin: NSObject, FlutterPlugin {
    public static func register(with registrar: FlutterPluginRegistrar) {
        let instance = MapboxMapFactory(withRegistrar: registrar)
        registrar.register(instance, withId: "plugins.flutter.io/mapmyindia_gl")

        let channel = FlutterMethodChannel(name: "plugins.flutter.io/mapmyindia_gl", binaryMessenger: registrar.messenger())

        channel.setMethodCallHandler { (methodCall, result) in
            switch(methodCall.method) {
            case "installOfflineMapTiles":
                guard let arguments = methodCall.arguments as? [String: String] else { return }
                let tilesdb = arguments["tilesdb"]
                installOfflineMapTiles(registrar: registrar, tilesdb: tilesdb!)
                result(nil)

            case "setRestAPIKey":
                guard let argumentsRestAPIKey = methodCall.arguments as? [String: String] else { return }
                let restAPIKey = argumentsRestAPIKey["restAPIKey"]
              
                MapmyIndiaAccountManager.setRestAPIKey(restAPIKey)
                result(nil)
                
            case "setMapSDKKey":
                guard let arguments = methodCall.arguments as? [String: String] else { return }
                let mapSDKKey = arguments["mapSDKKey"]
                MapmyIndiaAccountManager.setMapSDKKey(mapSDKKey)
                result(nil)
                
            case "setAtlasClientId":
                guard let arguments = methodCall.arguments as? [String: String] else { return }
                let atlasClientId = arguments["atlasClientId"]
                MapmyIndiaAccountManager.setAtlasGrantType("client_credentials")
                MapmyIndiaAccountManager.setAtlasClientId(atlasClientId)
                result(nil)
                
            case "setAtlasClientSecret":
                guard let arguments = methodCall.arguments as? [String: String] else { return }
                let atlasClientSecret = arguments["atlasClientSecret"]
                MapmyIndiaAccountManager.setAtlasClientSecret(atlasClientSecret)
                result(nil)
                
            case "setAtlasGrantType":
                guard let arguments = methodCall.arguments as? [String: String] else { return }
                let atlasGrantType = arguments["atlasGrantType"]
                MapmyIndiaAccountManager.setAtlasGrantType(atlasGrantType)
                result(nil)
                
            default:
                result(FlutterMethodNotImplemented)
            }
        }
    }

    private static func getTilesUrl() -> URL {
        guard var cachesUrl = FileManager.default.urls(for: .applicationSupportDirectory, in: .userDomainMask).first,
            let bundleId = Bundle.main.object(forInfoDictionaryKey: kCFBundleIdentifierKey as String) as? String else {
                fatalError("Could not get map tiles directory")
        }
        cachesUrl.appendPathComponent(bundleId)
        cachesUrl.appendPathComponent(".mapbox")
        cachesUrl.appendPathComponent("cache.db")
        return cachesUrl
    }

    // Copies the "offline" tiles to where Mapbox expects them
    private static func installOfflineMapTiles(registrar: FlutterPluginRegistrar, tilesdb: String) {
        var tilesUrl = getTilesUrl()
        let bundlePath = getTilesDbPath(registrar: registrar, tilesdb: tilesdb)
        NSLog("Cached tiles not found, copying from bundle... \(String(describing: bundlePath)) ==> \(tilesUrl)")
        do {
            let parentDir = tilesUrl.deletingLastPathComponent()
            try FileManager.default.createDirectory(at: parentDir, withIntermediateDirectories: true, attributes: nil)
            if FileManager.default.fileExists(atPath: tilesUrl.path) {
                try FileManager.default.removeItem(atPath: tilesUrl.path)
            }
            try FileManager.default.copyItem(atPath: bundlePath!, toPath: tilesUrl.path)
            var resourceValues = URLResourceValues()
            resourceValues.isExcludedFromBackup = true
            try tilesUrl.setResourceValues(resourceValues)
        } catch let error {
            NSLog("Error copying bundled tiles: \(error)")
        }
    }
    
    private static func getTilesDbPath(registrar: FlutterPluginRegistrar, tilesdb: String) -> String? {
        if (tilesdb.starts(with: "/")) {
            return tilesdb;
        } else {
            let key = registrar.lookupKey(forAsset: tilesdb)
            return Bundle.main.path(forResource: key, ofType: nil)
        }
    }
}
